jactorch.quickstart.inference
=============================

.. automodule:: jactorch.quickstart.inference

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AsyncInferenceTask
      AsyncModelInferencer
      BatchedAsyncModelInferencer
      ModelInferencer
   
   

   
   
   

   
   
   








.. rubric:: Class AsyncInferenceTask
.. autoclass:: AsyncInferenceTask
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class AsyncModelInferencer
.. autoclass:: AsyncModelInferencer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class BatchedAsyncModelInferencer
.. autoclass:: BatchedAsyncModelInferencer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ModelInferencer
.. autoclass:: ModelInferencer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







